/**
 * Copyright (C) cedarsoft GmbH.
 *
 * Licensed under the GNU General Public License version 3 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.cedarsoft.org/gpl3
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 3 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 3 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact cedarsoft GmbH, 72810 Gomaringen, Germany,
 * or visit www.cedarsoft.com if you need additional information or
 * have any questions.
 */

package com.cedarsoft.hudson.bears;

import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.concurrent.locks.ReadWriteLock;
import java.util.concurrent.locks.ReentrantReadWriteLock;

/**
 *
 */
public class PlugConnector {
  @NotNull
  @NonNls
  private final String server;
  @NotNull
  private final ReadWriteLock lock = new ReentrantReadWriteLock();


  public PlugConnector( @NotNull @NonNls String server ) {
    this.server = server;
  }

  /**
   * Switches the plugs
   *
   * @param states the states (first state switches the first plug)
   * @throws IOException
   */
  public void switchPlugs( @NotNull PlugState[] states ) throws IOException {
    for ( int i = 0; i < states.length; i++ ) {
      switchPlug( i, states[i] );
    }
  }

  public void disableAll() throws IOException {
    for ( int i = 0; i < 8; i++ ) {
      switchPlug( i, PlugState.OFF );
    }
  }

  public void switchPlug( int plugIndex, @NotNull PlugState state ) throws IOException {
    switchPlug( plugIndex, state == PlugState.ON );
  }

  public void switchPlug( int plugIndex, boolean enabled ) throws IOException {
    createUrl( plugIndex, enabled ).openStream().close();
  }

  @NotNull
  private URL createUrl( int plugIndex, boolean enabled ) throws MalformedURLException {
    int type = enabled ? 0 : 1;
    return new URL( "http", server, "ctrl.cgi?F" + plugIndex + "=" + type );
  }
}
